"""user: add api_key column

Revision ID: df7526f9612b
Revises: e88f8c7da784
Create Date: 2025-12-03 16:06:34.689747

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'df7526f9612b'
down_revision = 'e88f8c7da784'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('user', schema=None) as batch_op:
        batch_op.add_column(sa.Column('api_key', sa.String(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('user', schema=None) as batch_op:
        batch_op.drop_column('api_key')

    # ### end Alembic commands ###



"""initial schema

Revision ID: 000000000000
Revises:
Create Date: 2025-11-19 12:53:20.486640

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = '000000000000'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('list',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('name', sa.String(), nullable=False),
    sa.Column('address', sa.String(), nullable=False),
    sa.Column('from_addr', sa.String(), nullable=True),
    sa.Column('avoid_duplicates', sa.Boolean(), nullable=True),
    sa.Column('mode', sa.String(), nullable=False),
    sa.Column('only_subscribers_send', sa.Boolean(), nullable=True),
    sa.Column('allowed_senders', sa.JSON(), nullable=True),
    sa.Column('sender_auth', sa.JSON(), nullable=True),
    sa.Column('imap_host', sa.String(), nullable=False),
    sa.Column('imap_port', sa.Integer(), nullable=False),
    sa.Column('imap_user', sa.String(), nullable=False),
    sa.Column('imap_pass', sa.String(), nullable=False),
    sa.Column('deleted', sa.Boolean(), nullable=True),
    sa.Column('deleted_at', sa.DateTime(), nullable=True),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('address')
    )
    op.create_table('user',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('username', sa.String(length=100), nullable=False),
    sa.Column('password', sa.String(), nullable=False),
    sa.Column('role', sa.String(), nullable=True),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('username')
    )
    op.create_table('message',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('list_id', sa.Integer(), nullable=True),
    sa.Column('message_id', sa.String(), nullable=False),
    sa.Column('subject', sa.String(), nullable=True),
    sa.Column('from_addr', sa.String(), nullable=True),
    sa.Column('headers', sa.Text(), nullable=False),
    sa.Column('raw', sa.Text(), nullable=True),
    sa.Column('received_at', sa.DateTime(), nullable=True),
    sa.Column('status', sa.String(), nullable=True),
    sa.Column('error_info', sa.JSON(), nullable=True),
    sa.ForeignKeyConstraint(['list_id'], ['list.id'], ),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('message_id')
    )
    op.create_table('subscriber',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('list_id', sa.Integer(), nullable=False),
    sa.Column('name', sa.String(), nullable=True),
    sa.Column('email', sa.String(), nullable=False),
    sa.Column('comment', sa.String(), nullable=True),
    sa.Column('subscriber_type', sa.String(), nullable=True),
    sa.ForeignKeyConstraint(['list_id'], ['list.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('subscriber')
    op.drop_table('message')
    op.drop_table('user')
    op.drop_table('list')
    # ### end Alembic commands ###



"""list: make id a string, rename name -> display

Revision ID: b092089c847f
Revises: df7526f9612b
Create Date: 2025-12-08 21:57:12.351774

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'b092089c847f'
down_revision = 'df7526f9612b'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_in', schema=None) as batch_op:
        batch_op.alter_column('list_id',
               existing_type=sa.INTEGER(),
               type_=sa.String(),
               nullable=False)

    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.alter_column('list_id',
               existing_type=sa.INTEGER(),
               type_=sa.String(),
               existing_nullable=True)

    with op.batch_alter_table('list', schema=None) as batch_op:
        batch_op.alter_column('id',
               existing_type=sa.INTEGER(),
               type_=sa.String(),
               existing_nullable=False)
        batch_op.alter_column('name', new_column_name='display')

    with op.batch_alter_table('logs', schema=None) as batch_op:
        batch_op.alter_column('list_id',
               existing_type=sa.INTEGER(),
               type_=sa.String(),
               existing_nullable=True)

    with op.batch_alter_table('subscriber', schema=None) as batch_op:
        batch_op.alter_column('list_id',
               existing_type=sa.INTEGER(),
               type_=sa.String(),
               existing_nullable=False)

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('subscriber', schema=None) as batch_op:
        batch_op.alter_column('list_id',
               existing_type=sa.String(),
               type_=sa.INTEGER(),
               existing_nullable=False)

    with op.batch_alter_table('logs', schema=None) as batch_op:
        batch_op.alter_column('list_id',
               existing_type=sa.String(),
               type_=sa.INTEGER(),
               existing_nullable=True)

    with op.batch_alter_table('list', schema=None) as batch_op:
        batch_op.alter_column('id',
               existing_type=sa.String(),
               type_=sa.INTEGER(),
               existing_nullable=False)
        batch_op.alter_column('display', new_column_name='name')

    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.alter_column('list_id',
               existing_type=sa.String(),
               type_=sa.INTEGER(),
               existing_nullable=True)

    with op.batch_alter_table('email_in', schema=None) as batch_op:
        batch_op.alter_column('list_id',
               existing_type=sa.String(),
               type_=sa.INTEGER(),
               nullable=True)

    # ### end Alembic commands ###



"""email_out: store raw text of composed message

Revision ID: 37bb3a9da25f
Revises: 69ac95aabb62
Create Date: 2025-12-02 19:53:10.108217

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '37bb3a9da25f'
down_revision = '69ac95aabb62'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.add_column(sa.Column('raw', sa.Text(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.drop_column('raw')

    # ### end Alembic commands ###



"""email_out: create table relating to email_in

Revision ID: 4b9dee6df9e1
Revises: 33ec882b4a75
Create Date: 2025-12-02 15:54:38.730754

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '4b9dee6df9e1'
down_revision = '33ec882b4a75'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('email_out',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('email_in_mid', sa.String(), nullable=False),
    sa.Column('message_id', sa.String(), nullable=False),
    sa.Column('recipients', sa.JSON(), nullable=True),
    sa.Column('sent_at', sa.DateTime(), nullable=True),
    sa.ForeignKeyConstraint(['email_in_mid'], ['email_in.message_id'], ),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('message_id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('email_out')
    # ### end Alembic commands ###



"""email_out: add success/failure columns

Revision ID: a78bce7efae8
Revises: ad0a51791468
Create Date: 2025-12-02 17:34:42.116274

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'a78bce7efae8'
down_revision = 'ad0a51791468'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.add_column(sa.Column('sent_successful', sa.JSON(), nullable=True))
        batch_op.add_column(sa.Column('sent_failed', sa.JSON(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.drop_column('sent_failed')
        batch_op.drop_column('sent_successful')

    # ### end Alembic commands ###



"""list: display nullable

Revision ID: e73f5a16f3fd
Revises: b092089c847f
Create Date: 2025-12-08 22:35:49.879535

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e73f5a16f3fd'
down_revision = 'b092089c847f'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('list', schema=None) as batch_op:
        batch_op.alter_column('display',
               existing_type=sa.VARCHAR(),
               nullable=True)

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('list', schema=None) as batch_op:
        batch_op.alter_column('display',
               existing_type=sa.VARCHAR(),
               nullable=False)

    # ### end Alembic commands ###



"""email_out: store subject of composed message

Revision ID: e88f8c7da784
Revises: 37bb3a9da25f
Create Date: 2025-12-02 20:00:16.259806

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e88f8c7da784'
down_revision = '37bb3a9da25f'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.add_column(sa.Column('subject', sa.String(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.drop_column('subject')

    # ### end Alembic commands ###



"""message: change table name

Revision ID: 33ec882b4a75
Revises: 66a3243eacad
Create Date: 2025-12-02 15:13:31.498975

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import sqlite

# revision identifiers, used by Alembic.
revision = '33ec882b4a75'
down_revision = '66a3243eacad'
branch_labels = None
depends_on = None


def upgrade():
    op.rename_table('message', 'email_in')
    # ### end Alembic commands ###


def downgrade():
    op.rename_table('email_in', 'message')
    # ### end Alembic commands ###



"""logs: add table

Revision ID: 66a3243eacad
Revises: 000000000000
Create Date: 2025-12-01 17:08:08.109468

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '66a3243eacad'
down_revision = '000000000000'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('logs',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('timestamp', sa.DateTime(), nullable=True),
    sa.Column('level', sa.String(), nullable=False),
    sa.Column('event', sa.String(), nullable=False),
    sa.Column('message', sa.Text(), nullable=False),
    sa.Column('details', sa.JSON(), nullable=True),
    sa.Column('list_id', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['list_id'], ['list.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('logs')
    # ### end Alembic commands ###



"""email_in: make message_id primary key

Revision ID: 9f8b879d52ab
Revises: a78bce7efae8
Create Date: 2025-12-02 19:39:48.865835

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '9f8b879d52ab'
down_revision = 'a78bce7efae8'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_in', schema=None) as batch_op:
        batch_op.drop_column('id')

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_in', schema=None) as batch_op:
        batch_op.add_column(sa.Column('id', sa.INTEGER(), nullable=False))

    # ### end Alembic commands ###



"""email_out: add column for list_id

Revision ID: ad0a51791468
Revises: 4b9dee6df9e1
Create Date: 2025-12-02 17:12:01.085179

"""

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "ad0a51791468"
down_revision = "4b9dee6df9e1"
branch_labels = None
depends_on = None


def upgrade():
    with op.batch_alter_table("email_out", schema=None) as batch_op:
        batch_op.add_column(sa.Column("list_id", sa.Integer(), nullable=True))
        batch_op.create_foreign_key(
            "fk_email_out_list_id_list",
            "list",
            ["list_id"],
            ["id"],
        )


def downgrade():
    with op.batch_alter_table("email_out", schema=None) as batch_op:
        batch_op.drop_constraint(
            "fk_email_out_list_id_list",
            type_="foreignkey",
        )
        batch_op.drop_column("list_id")
